%{?!_licensedir:%global license %%doc}
%{!?upstream_version: %global upstream_version %{version}}

%global sname ironic-python-agent

Name:       openstack-ironic-python-agent
Summary:    A python agent for provisioning and deprovisioning bare metal servers
Version:    1.2.2
Release:    3%{?dist}
License:    ASL 2.0
URL:        https://github.com/openstack/ironic-python-agent

Source0:    http://tarballs.openstack.org/%{sname}/%{sname}-%{version}%{?milestone}.tar.gz
Source1:    openstack-ironic-python-agent.service

#patches_base=+2
Patch0017: 0017-Fix-unwanted-unmounting-of-usr-share-oem.patch

BuildArch:  noarch
BuildRequires:  python-setuptools
BuildRequires:  python-pbr
BuildRequires:  python-devel
BuildRequires:  systemd
Requires: python-ironic-python-agent = %{upstream_version}
Requires(post): systemd
Requires(preun): systemd
Requires(postun): systemd

# TODO(trown) when the following packages are available, package for py3:
# python3-eventlet
# python3-oslo-concurrency
# python3-oslo-i18n
# python3-oslo-log
# python3-oslo-serialization
# python3-oslo-service
# python3-oslo-utils
# python3-pecan
# python3-pint
# python3-wsme

%description
An agent for controlling and deploying Ironic controlled bare metal nodes.

The ironic-python-agent works with the agent driver in Ironic to provision the
node. Starting with ironic-python-agent running on a ramdisk on the
unprovisioned node, Ironic makes API calls to ironic-python-agent to provision
the machine. This allows for greater control and flexibility of the entire
deployment process.

The ironic-python-agent may also be used with the original Ironic pxe drivers
as of the Kilo OpenStack release.

%package -n python-ironic-python-agent
Summary:    Python library for the ironic python agent.
%{?python_provide:%python_provide python-ironic-python-agent}
# python_provide does not exist in CBS Cloud buildroot
Provides:   python-ironic-python-agent = %{upstream_version}

Requires: python-pbr
Requires: python-babel
Requires: python-eventlet
Requires: python-ironic-lib
Requires: python-iso8601
Requires: python-netifaces
Requires: python-oslo-config
Requires: python-oslo-concurrency
Requires: python-oslo-i18n
Requires: python-oslo-log
Requires: python-oslo-serialization
Requires: python-oslo-service
Requires: python-oslo-utils
Requires: python-pecan
Requires: python-pint
Requires: python-psutil
Requires: python-pyudev
Requires: python-requests
Requires: python-rtslib
Requires: python-six
Requires: python-stevedore
Requires: python-wsme

%description -n python-ironic-python-agent
Python library for ironic python agent.

%package -n python-ironic-python-agent-doc
Summary:    Documentation for ironic python agent.
%{?python_provide:%python_provide python-ironic-python-agent-doc}
# python_provide does not exist in CBS Cloud buildroot
Provides:   python-ironic-python-agent-doc = %{upstream_version}

%description -n python-ironic-python-agent-doc
Documentation for ironic python agent.

%prep
%autosetup -v -p 1 -n ironic-python-agent-%{upstream_version}

# Remove the requirements file so that pbr hooks don't add it
# to distutils requires_dist config
rm -rf {test-,}requirements.txt tools/{pip,test}-requires

%build
%{__python2} setup.py build

%install
%{__python2} setup.py install -O1 --skip-build --root=%{buildroot}

# TODO(trown) build the docs as below once we either remove the upstream
# requirement on python-sphinxcontrib-pecanwsme, or it exists in rawhide.
# For now, we will just include the raw restructured text.
# export PYTHONPATH="$( pwd ):$PYTHONPATH"
# pushd doc
# sphinx-build -b html -d build/doctrees  source build/html
# popd

# install systemd scripts
mkdir -p %{buildroot}%{_unitdir}
install -p -D -m 644 %{SOURCE1} %{buildroot}%{_unitdir}

install -p -D -m 644 etc/ironic_python_agent/ironic_python_agent.conf.sample %{buildroot}/%{_sysconfdir}/ironic-python-agent/agent.conf

%files
%doc README.rst
%license LICENSE
%config(noreplace) %attr(-,root,root) %{_sysconfdir}/ironic-python-agent
%{_bindir}/ironic-python-agent
%{_unitdir}/openstack-ironic-python-agent.service

%files -n python-ironic-python-agent
%license LICENSE
%{python2_sitelib}/ironic_python_agent
%{python2_sitelib}/ironic_python_agent*.egg-info

%files -n python-ironic-python-agent-doc
%doc doc/source
%license LICENSE

%post
%systemd_post openstack-ironic-python-agent.service

%preun
%systemd_preun openstack-ironic-python-agent.service

%postun
%systemd_postun_with_restart openstack-ironic-python-agent.service

%changelog
* Mon Jun 27 2016 Thierry Vignaud <<tvignaud@redhat.com>> 1.2.2-3
- Fix unwanted unmounting of /usr/share/oem
- Provide fallback from ATA erase to shredding
- Wait for at least one suitable disk to appear on start up
- TinyIPA: Shave off some file size from tinyipa ramdisk
- TinyIPA: Precompile python code for faster load
- Use TinyCore Linux 7.x for TinyIPA
- Optimise tinyipa boot time
- Enable branch tagging during tinyipa build
- Add script to install missing tinyipa dependencies
- Remove "Experimental" warning from tinyipa README
- [inspection] wait for the PXE DHCP by default and remove the carrier check
- Stop using git:// and be nice to people behind proxy servers
- Install qemu-image from backports repo
- Wait for the interfaces to get IP addresses before inspection
- Correct link to enabling agent drivers
- Fix full_trusty_build once and for all
- Append BRANCH_PATH to filenames of build output

* Mon Jun 20 2016 Mike Burns <mburns@redhat.com> 1.2.2-2
- Provide fallback from ATA erase to shredding
- Wait for at least one suitable disk to appear on start up
- TinyIPA: Shave off some file size from tinyipa ramdisk
- TinyIPA: Precompile python code for faster load
- Use TinyCore Linux 7.x for TinyIPA
- Optimise tinyipa boot time
- Enable branch tagging during tinyipa build
- Add script to install missing tinyipa dependencies
- Remove "Experimental" warning from tinyipa README
- [inspection] wait for the PXE DHCP by default and remove the carrier check
- Stop using git:// and be nice to people behind proxy servers
- Install qemu-image from backports repo
- Wait for the interfaces to get IP addresses before inspection
- Correct link to enabling agent drivers
- Fix full_trusty_build once and for all
- Append BRANCH_PATH to filenames of build output

* Thu Jun 09 2016 Thierry Vignaud <tvignaud@redhat.com> - 1.2.2-1
- Rebase to 1.2.2
- Remove merged patches

* Tue Jun 07 2016 Mike Burns <mburns@redhat.com> 1.2.0-4
- Provide fallback from ATA erase to shredding
- Wait for at least one suitable disk to appear on start up
- TinyIPA: Shave off some file size from tinyipa ramdisk
- TinyIPA: Precompile python code for faster load
- Use TinyCore Linux 7.x for TinyIPA
- Optimise tinyipa boot time
- Enable branch tagging during tinyipa build

* Fri May 13 2016 Mike Burns <mburns@redhat.com> 1.2.0-3
- Enable branch tagging during tinyipa build
- Stop using git:// and be nice to people behind proxy servers
- Add script to install missing tinyipa dependencies
- [inspection] wait for the PXE DHCP by default and remove the carrier check
- Wait for the interfaces to get IP addresses before inspection
- Install qemu-image from backports repo
- Add disk_label support for partition images
- Correct link to enabling agent drivers
- Fix full_trusty_build once and for all
- Append BRANCH_PATH to filenames of build output

* Wed Apr 06 2016 Dmitry Tantsur <dtantsur AT redhat.com> 1.2.0-2
- Depend on ironic-lib (new dependency in Mitaka)

* Wed Mar 30 2016 RDO <rdo-list@redhat.com> 1.2.0-0.1
- RC1 Rebuild for Mitaka RC1 
